|  | ID | IP Address | Protocol Port | Operating Status | Provisioning Status | Weight | Actions
--- | --- | --- | --- | --- | --- | --- | --- | ---
|  | {$ ::item.id $} | {$ ::item.address $} | {$ ::item.protocol_port $} | {$ ::item.operating_status | decode:table.operatingStatus $} | {$ ::item.provisioning_status | decode:table.provisioningStatus $} | {$ item.weight $} |
Monitor Address {$ ::item.monitor_address | noValue:('None' | translate) $} Monitor Port {$ ::item.monitor_port | noValue:('None' | translate) $}